@@ -97,17 +97,17 @@ class EmojiSimilarTestCase(unittest.TestCase):
         self.assertEqual(matches[0].phrase, '☺️')
         self.assertEqual(matches[0].comment, 'faccina sorridente [☺️, contorno faccina sorridente, delineata, emozionarsi, faccina, felice, rilassata, sorridente]')
         self.assertEqual(matches[0].user_freq, 8.0)
-        self.assertEqual(matches[1].phrase, '🤩')
-        self.assertEqual(matches[1].comment, 'colpo di fulmine [faccina, felice]')
+        self.assertEqual(matches[1].phrase, '😊')
+        self.assertEqual(matches[1].comment, 'faccina con occhi sorridenti [faccina, felice]')
         self.assertEqual(matches[1].user_freq, 2.0)
-        self.assertEqual(matches[2].phrase, '😊')
-        self.assertEqual(matches[2].comment, 'faccina con occhi sorridenti [faccina, felice]')
+        self.assertEqual(matches[2].phrase, '🙂')
+        self.assertEqual(matches[2].comment, 'faccina con sorriso accennato [faccina, felice]')
         self.assertEqual(matches[2].user_freq, 2.0)
-        self.assertEqual(matches[3].phrase, '🙂')
-        self.assertEqual(matches[3].comment, 'faccina con sorriso accennato [faccina, felice]')
+        self.assertEqual(matches[3].phrase, '😂')
+        self.assertEqual(matches[3].comment, 'faccina con lacrime di gioia [faccina, felice]')
         self.assertEqual(matches[3].user_freq, 2.0)
-        self.assertEqual(matches[4].phrase, '😂')
-        self.assertEqual(matches[4].comment, 'faccina con lacrime di gioia [faccina, felice]')
+        self.assertEqual(matches[4].phrase, '😃')
+        self.assertEqual(matches[4].comment, 'faccina con sorriso e occhi spalancati [felice, sorridente]')
         self.assertEqual(matches[4].user_freq, 2.0)
 
     def test_similar_camel_en_US(self) -> None:
